@@ -307,6 +307,7 @@ def register(eureka_server, instance):
         'homePageUrl': instance.homePageUrl,
         'statusPageUrl': instance.statusPageUrl,
         'healthCheckUrl': instance.healthCheckUrl,
+        'secureHealthCheckUrl': instance.secureHealthCheckUrl,
         'vipAddress': instance.vipAddress,
         'secureVipAddress': instance.secureVipAddress,
         'lastUpdatedTimestamp': str(instance.lastUpdatedTimestamp),
@@ -330,7 +331,9 @@ def cancel(eureka_server, app_name, instance_id):
 
 
 def send_heart_beat(eureka_server, app_name, instance_id, last_dirty_timestamp, status=INSTANCE_STATUS_UP, overriddenstatus=""):
-    url = _format_url(eureka_server) + "apps/%s/%s?status=%s&lastDirtyTimestamp=%s" % \
+    #url = _format_url(eureka_server) + "apps/%s/%s?status=%s&lastDirtyTimestamp=%s" % \
+    #    (app_name, instance_id, status, str(last_dirty_timestamp))
+    url = _format_url(eureka_server) + "apps/%s/%s/status?value=%s&lastDirtyTimestamp=%s" % \
         (app_name, instance_id, status, str(last_dirty_timestamp))
     _logger.debug("heartbeat url::" + url)
     if overriddenstatus != "":
@@ -386,7 +389,7 @@ def _build_applications(xml_node):
     if xml_node.tag != "applications":
         return None
     applications = Applications()
-    for child_node in xml_node.getchildren():
+    for child_node in list(xml_node):
         if child_node.tag == "versions__delta" and child_node.text is not None:
             applications.versions__delta = child_node.text
         elif child_node.tag == "apps__hashcode" and child_node.text is not None:
@@ -470,14 +473,14 @@ def _build_instance(xml_node):
 
 def _build_metadata(xml_node):
     metadata = {}
-    for child_node in xml_node.getchildren():
+    for child_node in list(xml_node):
         metadata[child_node.tag] = child_node.text
     return metadata
 
 
 def _build_lease_info(xml_node):
     leaseInfo = LeaseInfo()
-    for child_node in xml_node.getchildren():
+    for child_node in list(xml_node):
         if child_node.tag == "renewalIntervalInSecs":
             leaseInfo.renewalIntervalInSecs = int(child_node.text)
         elif child_node.tag == "durationInSecs":
@@ -561,6 +564,7 @@ class RegistryClient:
                  home_page_url="",
                  status_page_url="",
                  health_check_url="",
+                 secure_health_check_url="",
                  vip_adr="",
                  secure_vip_addr="",
                  is_coordinating_discovery_server=False,
@@ -622,6 +626,7 @@ class RegistryClient:
             'homePageUrl': RegistryClient.__format_url(home_page_url, self.__instance_host, instance_port),
             'statusPageUrl': RegistryClient.__format_url(status_page_url, self.__instance_host, instance_port, "info"),
             'healthCheckUrl': RegistryClient.__format_url(health_check_url, self.__instance_host, instance_port, "health"),
+            'secureHealthCheckUrl': secure_health_check_url,
             'vipAddress': vip_adr if vip_adr != "" else app_name.lower(),
             'secureVipAddress': secure_vip_addr if secure_vip_addr != "" else app_name.lower(),
             'isCoordinatingDiscoveryServer': str(is_coordinating_discovery_server).lower()
@@ -676,7 +681,7 @@ class RegistryClient:
         target_ip = url_obj["host"]
         target_port = url_obj["port"]
         if target_port is None:
-            if url_obj["scheme"] == "http":
+            if url_obj["schema"] == "http":
                 target_port = 80
             else:
                 target_port = 443
@@ -776,6 +781,7 @@ def init_registry_client(eureka_server=_DEFAULT_EUREKA_SERVER_URL,
                          home_page_url="",
                          status_page_url="",
                          health_check_url="",
+                         secure_health_check_url="",
                          vip_adr="",
                          secure_vip_addr="",
                          is_coordinating_discovery_server=False,
@@ -797,6 +803,7 @@ def init_registry_client(eureka_server=_DEFAULT_EUREKA_SERVER_URL,
                                 home_page_url=home_page_url,
                                 status_page_url=status_page_url,
                                 health_check_url=health_check_url,
+                                secure_health_check_url=secure_health_check_url,
                                 vip_adr=vip_adr,
                                 secure_vip_addr=secure_vip_addr,
                                 is_coordinating_discovery_server=is_coordinating_discovery_server,
@@ -1137,6 +1144,7 @@ def init(eureka_server=_DEFAULT_EUREKA_SERVER_URL,
          home_page_url="",
          status_page_url="",
          health_check_url="",
+         secure_health_check_url="",
          vip_adr="",
          secure_vip_addr="",
          is_coordinating_discovery_server=False,
@@ -1158,6 +1166,7 @@ def init(eureka_server=_DEFAULT_EUREKA_SERVER_URL,
                                            home_page_url=home_page_url,
                                            status_page_url=status_page_url,
                                            health_check_url=health_check_url,
+                                           secure_health_check_url=secure_health_check_url,
                                            vip_adr=vip_adr,
                                            secure_vip_addr=secure_vip_addr,
                                            is_coordinating_discovery_server=is_coordinating_discovery_server,
